( cd usr/share/doc/HTML/pl/ark ; rm -rf common )
( cd usr/share/doc/HTML/pl/ark ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kdf ; rm -rf common )
( cd usr/share/doc/HTML/pl/kdf ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kdm ; rm -rf common )
( cd usr/share/doc/HTML/pl/kdm ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kig ; rm -rf common )
( cd usr/share/doc/HTML/pl/kig ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kpf ; rm -rf common )
( cd usr/share/doc/HTML/pl/kpf ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/pl/ktuberling ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/amor ; rm -rf common )
( cd usr/share/doc/HTML/pl/amor ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kate ; rm -rf common )
( cd usr/share/doc/HTML/pl/kate ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kget ; rm -rf common )
( cd usr/share/doc/HTML/pl/kget ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kmid ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmid ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kmix ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmix ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kpat ; rm -rf common )
( cd usr/share/doc/HTML/pl/kpat ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kpdf ; rm -rf common )
( cd usr/share/doc/HTML/pl/kpdf ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kppp ; rm -rf common )
( cd usr/share/doc/HTML/pl/kppp ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/krdc ; rm -rf common )
( cd usr/share/doc/HTML/pl/krdc ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/krfb ; rm -rf common )
( cd usr/share/doc/HTML/pl/krfb ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kscd ; rm -rf common )
( cd usr/share/doc/HTML/pl/kscd ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kxkb ; rm -rf common )
( cd usr/share/doc/HTML/pl/kxkb ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kalzium ; rm -rf common )
( cd usr/share/doc/HTML/pl/kalzium ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/katomic ; rm -rf common )
( cd usr/share/doc/HTML/pl/katomic ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksysguard ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksysguard ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kbounce ; rm -rf common )
( cd usr/share/doc/HTML/pl/kbounce ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kbattleship ; rm -rf common )
( cd usr/share/doc/HTML/pl/kbattleship ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khangman ; rm -rf common )
( cd usr/share/doc/HTML/pl/khangman ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kfloppy ; rm -rf common )
( cd usr/share/doc/HTML/pl/kfloppy ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khexedit ; rm -rf common )
( cd usr/share/doc/HTML/pl/khexedit ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kpercentage ; rm -rf common )
( cd usr/share/doc/HTML/pl/kpercentage ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcalc ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kdcop ; rm -rf common )
( cd usr/share/doc/HTML/pl/kdcop ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kdesu ; rm -rf common )
( cd usr/share/doc/HTML/pl/kdesu ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcron ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcron ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kfind ; rm -rf common )
( cd usr/share/doc/HTML/pl/kfind ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kiten ; rm -rf common )
( cd usr/share/doc/HTML/pl/kiten ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kjots ; rm -rf common )
( cd usr/share/doc/HTML/pl/kjots ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kmail ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmail ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksame ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksame ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksirc ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksirc ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kuser ; rm -rf common )
( cd usr/share/doc/HTML/pl/kuser ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kview ; rm -rf common )
( cd usr/share/doc/HTML/pl/kview ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kwin4 ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwin4 ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/klipper ; rm -rf common )
( cd usr/share/doc/HTML/pl/klipper ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kvoctrain ; rm -rf common )
( cd usr/share/doc/HTML/pl/kvoctrain ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kompmgr ; rm -rf common )
( cd usr/share/doc/HTML/pl/kompmgr ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kontact ; rm -rf common )
( cd usr/share/doc/HTML/pl/kontact ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konsole ; rm -rf common )
( cd usr/share/doc/HTML/pl/konsole ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kanagram ; rm -rf common )
( cd usr/share/doc/HTML/pl/kanagram ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khelpcenter/faq ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/faq ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khelpcenter/quickstart ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/quickstart ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khelpcenter/glossary ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khelpcenter ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khelpcenter/userguide ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/userguide ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/khelpcenter/visualdict ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/visualdict ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksirtet ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksirtet ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konquest ; rm -rf common )
( cd usr/share/doc/HTML/pl/konquest ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/akregator ; rm -rf common )
( cd usr/share/doc/HTML/pl/akregator ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kturtle ; rm -rf common )
( cd usr/share/doc/HTML/pl/kturtle ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kverbos ; rm -rf common )
( cd usr/share/doc/HTML/pl/kverbos ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwallet ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kweather ; rm -rf common )
( cd usr/share/doc/HTML/pl/kweather ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kwifimanager ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwifimanager ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kmenuedit ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmenuedit ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kioslave ; rm -rf common )
( cd usr/share/doc/HTML/pl/kioslave ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kbackgammon ; rm -rf common )
( cd usr/share/doc/HTML/pl/kbackgammon ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/knetattach ; rm -rf common )
( cd usr/share/doc/HTML/pl/knetattach ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kaddressbook ; rm -rf common )
( cd usr/share/doc/HTML/pl/kaddressbook ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/common ; rm -rf fdl-license )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd usr/share/doc/HTML/pl/common ; rm -rf qpl-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf favicon.ico )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/favicon.ico favicon.ico )
( cd usr/share/doc/HTML/pl/common ; rm -rf x11-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf 1.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/1.png 1.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf xml.dcl )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd usr/share/doc/HTML/pl/common ; rm -rf 2.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/2.png 2.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 3.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/3.png 3.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 4.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/4.png 4.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 5.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/5.png 5.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 6.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/6.png 6.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 7.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/7.png 7.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf top-right-konqueror.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 8.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/8.png 8.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 9.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/9.png 9.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf headerbg.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf gpl-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf mainheader.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf grad.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/grad.png grad.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf fdl-notice.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/fdl-notice.html fdl-notice.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde-web.css )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde_logo_bg.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf lgpl-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf doxygen.css )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd usr/share/doc/HTML/pl/common ; rm -rf web-doctop.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde-default.css )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd usr/share/doc/HTML/pl/common ; rm -rf kmenu.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf footer.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/footer.html footer.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde-common.css )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd usr/share/doc/HTML/pl/common ; rm -rf bottom-left.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf appheader.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf doctop1.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf doctop2.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf shadow.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde_logo.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf docheadergears.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf top-middle.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf fdl-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf bottom-right.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf doctop1a.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf 10.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/10.png 10.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf doctop1b.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf lgpl-license )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd usr/share/doc/HTML/pl/common ; rm -rf mainfooter.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf bottom1.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf bottom2.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf header.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/header.html header.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf bottom-middle.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf top-left.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/top-left.png top-left.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf gpl-license )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde-localised.css.template )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd usr/share/doc/HTML/pl/common ; rm -rf bsd-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf web-docbottom.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd usr/share/doc/HTML/pl/common ; rm -rf artistic-license.html )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd usr/share/doc/HTML/pl/common ; rm -rf kde_gear_64.png )
( cd usr/share/doc/HTML/pl/common ; ln -sf ../../en/common/kde_gear_64.png kde_gear_64.png )
( cd usr/share/doc/HTML/pl/kcontrol/kdm ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kdm ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/smb ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/smb ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/spellchecking ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/bell ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/bell ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/arts ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/arts ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/keys ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/keys ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/powerctrl ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/powerctrl ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/cookies ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/filetypes ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/desktop ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/desktop ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/cache ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/cache ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/clock ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/clock ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/email ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/email ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/fonts ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/fonts ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/khtml ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/khtml ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/filemanager ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/mouse ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/mouse ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/panel ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/panel ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/proxy ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/desktopbehavior ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/desktopbehavior ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/passwords ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/passwords ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/panelappearance ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/panelappearance ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/ebrowsing ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/background ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/background ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmaccess ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmaccess ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/colors ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/colors ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/crypto ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/crypto ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/energy ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/energy ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmstyle ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmstyle ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/netpref ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmlaunch ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmcss ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/laptop ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/laptop ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmnotify ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmsmserver ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmsmserver ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/screensaver ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/screensaver ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/windowmanagement ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/windowmanagement ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kwindecoration ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kwindecoration ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmkonsole ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmkonsole ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/language ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/language ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/useragent ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/helpindex ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/helpindex ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmlowbatcrit ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmlowbatwarn ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmtaskbar ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmtaskbar ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmfontinst ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcmfontinst ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kcontrol/performance ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/performance ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/crashes ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/crashes ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/babel ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/babel ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/kuick ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/kuick ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/webarchiver ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/webarchiver ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/domtreeviewer ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/domtreeviewer ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/imgallery ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/imgallery ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/khtmlsettings ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/khtmlsettings ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/validators ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/validators ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/fsview ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/fsview ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/uachanger ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/uachanger ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/mediaplayer ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/mediaplayer ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konq-plugins/dirfilter ; rm -rf common )
( cd usr/share/doc/HTML/pl/konq-plugins/dirfilter ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kaudiocreator ; rm -rf common )
( cd usr/share/doc/HTML/pl/kaudiocreator ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kdeprint ; rm -rf common )
( cd usr/share/doc/HTML/pl/kdeprint ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/pl/kbruch ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/keduca ; rm -rf common )
( cd usr/share/doc/HTML/pl/keduca ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kicker ; rm -rf common )
( cd usr/share/doc/HTML/pl/kicker ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/klatin ; rm -rf common )
( cd usr/share/doc/HTML/pl/klatin ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/klines ; rm -rf common )
( cd usr/share/doc/HTML/pl/klines ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kmines ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmines ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kmplot ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmplot ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/knotes ; rm -rf common )
( cd usr/share/doc/HTML/pl/knotes ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kpager ; rm -rf common )
( cd usr/share/doc/HTML/pl/kpager ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kopete ; rm -rf common )
( cd usr/share/doc/HTML/pl/kopete ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksnake ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksnake ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kspell ; rm -rf common )
( cd usr/share/doc/HTML/pl/kspell ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kstars ; rm -rf common )
( cd usr/share/doc/HTML/pl/kstars ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/pl/ktouch ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwrite ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kreversi ; rm -rf common )
( cd usr/share/doc/HTML/pl/kreversi ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/noatun ; rm -rf common )
( cd usr/share/doc/HTML/pl/noatun ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksplashml ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksplashml ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/superkaramba ; rm -rf common )
( cd usr/share/doc/HTML/pl/superkaramba ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kolourpaint ; rm -rf common )
( cd usr/share/doc/HTML/pl/kolourpaint ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/klettres ; rm -rf common )
( cd usr/share/doc/HTML/pl/klettres ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/klickety ; rm -rf common )
( cd usr/share/doc/HTML/pl/klickety ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kfilereplace ; rm -rf common )
( cd usr/share/doc/HTML/pl/kfilereplace ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kgeography ; rm -rf common )
( cd usr/share/doc/HTML/pl/kgeography ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kjumpingcube ; rm -rf common )
( cd usr/share/doc/HTML/pl/kjumpingcube ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/blinken ; rm -rf common )
( cd usr/share/doc/HTML/pl/blinken ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/KRegExpEditor ; rm -rf common )
( cd usr/share/doc/HTML/pl/KRegExpEditor ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/ksokoban ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksokoban ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/knetworkconf ; rm -rf common )
( cd usr/share/doc/HTML/pl/knetworkconf ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/dma ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/dma ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/pci ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/pci ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/usb ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/usb ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/nics ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/nics ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/scsi ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/scsi ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/interrupts ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/interrupts ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/devices ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/devices ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/blockdevices ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/blockdevices ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/xserver ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/xserver ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/samba ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/samba ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/sound ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/sound ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/partitions ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/partitions ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/cdinfo ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/cdinfo ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/memory ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/memory ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/pcmcia ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/pcmcia ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/opengl ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/opengl ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/processor ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/processor ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/ioports ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/ioports ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kinfocenter/protocols ; rm -rf common )
( cd usr/share/doc/HTML/pl/kinfocenter/protocols ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kate-plugins ; rm -rf common )
( cd usr/share/doc/HTML/pl/kate-plugins ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/konqueror ; rm -rf common )
( cd usr/share/doc/HTML/pl/konqueror ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwordquiz ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pl/korganizer ; rm -rf common )
( cd usr/share/doc/HTML/pl/korganizer ; ln -sf /usr/share/doc/HTML/pl/common common )
